@@ -1,12 +1,16 @@
-from typing import Any, Dict, Iterable, Optional, Sequence
+from typing import Any, Dict, Iterable, Optional, Sequence, Type, TypeVar
 
 from django.db import models
+from django.db import connection
 from django.contrib.postgres.functions import TransactionNow
 from django.contrib.postgres.fields import JSONField
 
 DEFAULT_QUEUE_NAME = "default"
 
 
+_Self = TypeVar("_Self", bound="BaseJob")
+
+
 class BaseJob(models.Model):
     id = models.BigAutoField(primary_key=True)
     created_at = models.DateTimeField(default=TransactionNow)
@@ -34,11 +38,11 @@ class BaseJob(models.Model):
 
     @classmethod
     def dequeue(
-        cls,
+        cls: Type[_Self],
         exclude_ids: Optional[Iterable[int]] = None,
         tasks: Optional[Sequence[str]] = None,
         queue: str = DEFAULT_QUEUE_NAME,
-    ) -> Optional["BaseJob"]:
+    ) -> Optional[_Self]:
         """
         Claims the first available task and returns it. If there are no
         tasks available, returns None.
@@ -60,13 +64,13 @@ class BaseJob(models.Model):
             WHERE += " AND TASK = ANY(%s)"
             args.append(tasks)
 
-        jobs: Sequence[BaseJob] = list(
+        jobs = list(
             cls.objects.raw(
                 """
-            DELETE FROM pgq_job
+            DELETE FROM {db_table}
             WHERE id = (
                 SELECT id
-                FROM pgq_job
+                FROM {db_table}
                 {WHERE}
                 ORDER BY priority DESC, created_at
                 FOR UPDATE SKIP LOCKED
@@ -74,7 +78,7 @@ class BaseJob(models.Model):
             )
             RETURNING *;
             """.format(
-                    WHERE=WHERE
+                    db_table=connection.ops.quote_name(cls._meta.db_table), WHERE=WHERE
                 ),
                 args,
             )
